<?php 
/**
	Functions.php
	@package f13 folio
	@since f13 folio 4.0
	
	F13 Studio ~ http://f13.tv 
	Martin Knoll ~ me@f13.tv
	Twitter @martyish
	
*/


error_reporting(0);

// make all functions use default timezone
//date_default_timezone_set('Australia/Adelaide');
//date_default_timezone_set("UTC");

// require for add thumb //
require_once(ABSPATH . 'wp-admin/includes/media.php');
require_once(ABSPATH . 'wp-admin/includes/file.php');
require_once(ABSPATH . 'wp-admin/includes/image.php');



/////////////////////
// THEME FUNCTIONS //
/////////////////////

add_action('after_setup_theme', 'f13_setup');

function f13_setup() {

	// add RSS to head and make menus
	add_theme_support('automatic-feed-links');
	register_nav_menus(array(
		'top' => __('Top Strip', 'f13'),
		'footer' => __('Footer Menu', 'f13'),
		'social' => __('Social Links', 'f13'),
	));

	// post format support. you can also use the legacy "gallery" or "asides" (note the plural) categories.
	add_theme_support('post-formats', array( 'video', 'image', 'gallery', 'audio', /*'aside', 'status' , 'quote', 'link', 'chat'*/ ));

	add_post_type_support('page','excerpt'); // add excerpt
	add_theme_support('post-thumbnails'); // use thumbnails
	add_image_size('square', '200', '200', true ); // for mosaique
	add_image_size('16x9_small', '600', '338', true ); // used for thumbnails
	add_image_size('16x9_medium', '1280', '720', true ); // used to display
	add_image_size('16x9_large', '2560', '1440', true ); // may be used instead of full
	add_image_size('16x9_red2540p', '4520', '2543', true ); // red epic 4k	
	
	// this theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style(); 
	
	// add categories to attachments  
	function attachments_taxonomy() {
		//register_taxonomy_for_object_type( 'category', 'attachment' );  
		register_taxonomy_for_object_type( 'post_tag', 'attachment' );
		register_taxonomy_for_object_type( 'tag', 'attachment' );  
	}  
	add_action( 'init' , 'attachments_taxonomy' ); 
	
	// add extra exif fields
	function add_attachment_exif() {		
		$args['location'] = array(
			'labels' => array(
				'name'              => 'Locations',
				'singular_name'     => 'Location',
				'search_items'      => 'Search locations',
				'all_items'         => 'All locations',
				'parent_item'       => 'Parent location',
				'parent_item_colon' => 'Parent location:',
				'edit_item'         => 'Edit location',
				'update_item'       => 'Update location',
				'add_new_item'      => 'Add new location',
				'new_item_name'     => 'New location name',
				'menu_name'         => 'Location',
			),
			'hierarchical' => true,
			'query_var' => 'true',
			'rewrite' => 'true',
			'show_admin_column' => 'false',
		);			
		$args['lens'] = array(
			'labels' => array(
				'name'              => 'Lenses',
				'singular_name'     => 'Lens',
				'search_items'      => 'Search lenses',
				'all_items'         => 'All lenses',
				'parent_item'       => 'Parent lens type',
				'parent_item_colon' => 'Parent lens type:',
				'edit_item'         => 'Edit lens',
				'update_item'       => 'Update lens',
				'add_new_item'      => 'Add new lens',
				'new_item_name'     => 'New lens type',
				'menu_name'         => 'Lens type',
			),
			'hierarchical' => true,
			'query_var' => 'true',
			'rewrite' => 'true',
			'show_admin_column' => 'false',
		);
		register_taxonomy( 'location', 'attachment', $args['location'] );
		register_taxonomy( 'lens', 'attachment', $args['lens'] );
	}
//	add_action( 'init', 'add_attachment_exif' );

	// make theme available for translation.
	// Translations can be filed in the /languages/ directory.
	//load_theme_textdomain('twentytwelve', get_template_directory() .'/languages');
	//$locale = get_locale();
	//$locale_file = get_template_directory().'/languages/$locale.php';
	//if (is_readable($locale_file)) require_once($locale_file);

	// title format
	function theme_name_wp_title( $title, $sep ) {
	
		if (is_feed()) return $title;	
		global $page, $paged;
	
		// add the blog name.
		$title .= get_bloginfo('name','display');
		
		// add the blog description for the home/front page.
		$site_description = get_bloginfo('description','display');
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title .= " $sep $site_description";
		}
		
		// add a page number if necessary.
		if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
			$title .= " $sep " . sprintf( __( 'Page %s', '_s' ), max( $paged, $page ) );
		}
		
		return $title;
		
	}
	add_filter( 'wp_title', 'theme_name_wp_title', 10, 2 );


	/////////////////////
	// cron management //
	/////////////////////
	function add_new_intervals($schedules) { 
		$schedules['minute'] = array('interval' => 60, 'display' => __('Minutely')); 
		$schedules['hour'] = array('interval' => 3600, 'display' => __('Hourly')); 
		$schedules['day'] = array('interval' => 86400, 'display' => __('Daily')); 
		return $schedules; 
	} 
	add_filter('cron_schedules', 'add_new_intervals'); 
	
	// add event 
	add_action('import_media', 'import_media');	
	add_action('update_shares', 'update_shares'); 
	function my_activation() { 
		if ( !wp_next_scheduled( 'import_media' ) ) wp_schedule_event(time(), 'minute', 'import_media'); 
		if ( !wp_next_scheduled( 'update_shares' ) ) wp_schedule_event(time(), 'day', 'update_shares'); 
		/*if ( !wp_next_scheduled( 'import_instagram' ) ) wp_schedule_event(time(), 'minute', 'import_instagram');*/
	} 
	add_action('wp', 'my_activation'); 
	
} 
// END THEME FUNCTIONS //


// Hide protected posts
function exclude_protected($where) {
	global $wpdb;
	return $where .= " AND {$wpdb->posts}.post_password = '' ";
}

// Where to display protected posts
function exclude_protected_action($query) {
	if( !is_single() && !is_page() && !is_admin() ) {
		add_filter( 'posts_where', 'exclude_protected' );
	}
}

// Action to queue the filter at the right time
add_action('pre_get_posts', 'exclude_protected_action');

// keep revisions low
define('WP_POST_REVISIONS', 5);


/////////////////////////////////
// Cron Jobs (activated above) //
/////////////////////////////////	
// ** function import_media($src, $dst) {
function import_media($src='f13.tv/media', $dst='f13.tv/media/_archive') {

	$base = '/home7/clearco3/public_html/';
	$ignore = array('_archive','_hide','_data','_watermark','index.php','error_log');

// ** if(!$src) $src = 'f13.tv/media';
// ** if(!$dst) $dst = 'f13.tv/media/_archive';
	
	if (!file_exists($base.$dst)) mkdir($base.$dst, 0777, true);
	$dir = opendir($base.$src);
	
	if ($dir) {
	
		// process files 
		while(false !== ( $file = readdir($dir)) ) { 
			if ( ($file != '.') && ($file != '..') && !in_array($file,$ignore) ) { 
				if ( is_dir($base.$src.'/'.$file) ) { 
				
					import_media($src.'/'.$file, $dst.'/'.$file); 
					
				} else { 
				
					$size = getimagesize($base.$src.'/'.$file); 
					
					// exif data //
					$exif = exif_read_data ($base.$src.'/'.$file); 
					$fields = array(
					// hardware //
						//'Make',
						'Model', // already says make
						'FirmwareVersion', // camera firmware
						'Serial' => 'UndefinedTag:0xA431', // 'camera serial'
						'LensModel' => 'UndefinedTag:0xA434', // Lens Name
						'LensSerial' => 'UndefinedTag:0xA435', // Lens Serial Canon
						
					// user details //
						'OwnerName', // 'Martin Knoll'
						'Artist', // 'Marty Knoll @martyish'
						'Copyright', // 'www.f13.tv marty@f13.tv	
						
					// photo details //	
						
						'Orientation', // 1
						'ExposureTime', // '1/30'
						'FNumber', // '12/10'
						'ExposureProgram', // 1
						'ISOSpeedRatings', // 640
						'ShutterSpeedValue', // '327680/65536'
						'ApertureValue', // '40960/65536'
						'ExposureBiasValue', // '0/1'
						'MeteringMode', // 2
						'Flash', // 16
						'FocalLength', // '50/1'
						'ExposureMode', // 1
						'WhiteBalance', // 0
						'SceneCaptureType', // 0
						'GPSVersion',
						'GPSLatitudeRef','GPSLatitude','GPSLongitudeRef','GPSLongitude',
						
						//'XResolution', // '72/1'
						//'YResolution', // '72/1'
						//'ResolutionUnit', // 2
						//'YCbCrPositioning', // 2
						
					// file details //
						
						//'ImageType',
						//'FileName',
						'FileDateTime',
						//'FileSize',
						//'FileType', // 2
						//'MimeType', // 'image/jpeg'
						 
						//'DateTime', // '2015:04:23 02:23:56'
						//'DateTimeOriginal', // '2015:04:23 02:23:56'
						//'DateTimeDigitized', // '2015:04:23 02:23:56'
							
						'COMPUTED',	
					);
					
					/*	
						//'GPS_IFD_Pointer', // 9362
						//'ExifVersion', // '0230'
						//'Exif_IFD_Pointer', // 270
						//'UndefinedTag:0x8830', // 2
						//'UndefinedTag:0x8832', // 640
						//'SubSecTime', // '55'
						//'SubSecTimeOriginal', // '55'
						//'SubSecTimeDigitized', // '55'
						//'FlashPixVersion', // '0100'
						//'ColorSpace', // 1
						//'ExifImageWidth', // 720
						//'ExifImageLength', // 480
						//'InteroperabilityOffset', // 9332
						//'FocalPlaneXResolution', // '720000/1461'
						//'FocalPlaneYResolution', // '480000/972'
						//'FocalPlaneResolutionUnit', // 2
						//'CustomRendered', // 0
						//'UndefinedTag:0xA430', // 'Martin Knoll'
						//'InterOperabilityIndex',
						//'InterOperabilityVersion',
						// 'THUMBNAIL',
					*/

					foreach ($exif as $k => $v) if(in_array($k,$fields)) {
						$field = array_keys($fields,$k)[0];
						if(is_numeric($field)) $field = $k;
						$d[$field] = $v; 
					}

					$device = 'Photo taken by '.$d['Artist'].' on the '.date('jS F \a\t g:ia', $d['FileDateTime']).' using a '.$d['Model'].' ('.$d['Serial'].') with a '.$d['LensModel'].' ('.$d['LensSerial'].') '.$d['Copyright'];
					
					$photo = "
						FocalLength: ".$d['FocalLength']." 
						ExposureTime: ".$d['ExposureTime']." 
						ApertureFNumber: ".$d['COMPUTED']['ApertureFNumber']." 
					\n\n";
					
					$del = array("\n","\r");
					$device = str_replace($del, " ", $device);
					
					$message = $device."\n \r".$photo;
					
					//if ($exif[ExifImageLength]==$size[1]||$exif[ExifImageLength]==$size[0]) { 
						rename($base.$src.'/'.$file, $base.$dst.'/'.$file); 
						media_sideload_image('http://'.$dst.'/'.$file, '456', $file.' ~ '.$message); 
						//mail('marty@f13.tv', 'media imported', 'http://'.$dst.'/'.$file.' '.$message.' ### '.var_export($exif,'true')); 
					//} 
					
				} 
			} 
		} 
		closedir($dir); 
	} 
	//slack(time().'_import-media*minutely','cron');
}

function update_shares() {
	$args = array(
		'post_status' => 'publish',
		'post_type' => array('post','page'),
		'fields' => 'ids',
		'posts_per_page' => -1,
	);
	$query = new WP_Query($args);
	foreach ($query->posts as $id) {
		$total = total(/*$post->guid,*/get_permalink($id),wp_get_shortlink($id));
		update_post_meta($id, 'shares',$total);
	}
	//slack(time().'_update-shares*daily','cron');
} 



/////////////////
// Short Codes //
/////////////////

function linkHead() {
	return '<h1>Links</h1>
	<a href="http://f13.tv/~#~facebook" target="_blank">Check out the album on facebook.. Like and tag away</a><br/>
	<a href="http://f13.tv/~#~photos" target="_blank">Complete Photo Album</a><br/>
	<a href="https://www.facebook.com/events/~#~/" target="_blank">Event Page on Facebook</a>';
}
add_shortcode('linkhead', 'linkHead');


/*
/////////////////////
// Infinate Scroll //
/////////////////////
function wp_infinitepaginate(){ 
    $loopFile        = $_POST['loop_file'];
    $paged           = $_POST['page_no'];
    $posts_per_page  = get_option('posts_per_page');
 
    # Load the posts
    query_posts(array('paged' => $paged )); 
    get_template_part( $loopFile );
 
    exit;
}
add_action('wp_ajax_infinite_scroll', 'wp_infinitepaginate');           // for logged in user
add_action('wp_ajax_nopriv_infinite_scroll', 'wp_infinitepaginate');    // if user not logged in
*/


////////////////
// Formatting //
////////////////

// New 2016 Version //
function get_article($id) { if ($id) {

	// SET COMMON VARS ONCE //
	$article->title = __(get_the_title($id)); 
	$article->permalink = get_permalink($id); 
	$article->shortlink = wp_get_shortlink($id); 
	$article->time_stamp = stamp(get_post_field('post_date', $id)); 
	if ( !$article->excerpt = __(get_the_excerpt($id)) ) $article->excerpt = get_post_field('post_content', $id);
		
	// PROCESS FEATURED IMAGE & STORE //
	if (!has_post_thumbnail($id)) {
	
		if ($media_id=get_inline_media(get_post_field('post_content', $id), true)) { 
			// if vimeo id get data
			$vimeo_data = vimeo($media_id);	
			media_sideload_image( $vimeo_data['thumbnail_url'], $post->ID, $vimeo_data['description'] );
			$attachment = get_children( array (
				'post_parent'    => $id,
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'posts_per_page'  => (int)1
			), ARRAY_A );		
			$article->featured = key($attachment);
		} else {
			// otherwise set first image or default
			preg_match_all('/<img[^>]+src\s*=\s*["\']?([^"\' ]+)[^>]*>/', get_post_field('post_content', $id), $images);
			if ($article->featured=get_attachment_id($images[1][0])) {
				media_sideload_image( $images[1][0], $id, $article->title);
				$attachment = get_children( array (
					'post_parent'    => $id,
					'post_type'      => 'attachment',
					'post_mime_type' => 'image',
					'posts_per_page'  => (int)1
				), ARRAY_A );		
				$article->featured = key($attachment);
			} else $article->featured = '178';
		} 
		// set thumbnail for good
		set_post_thumbnail( $id, $article->featured); 
	
	} else $article->featured = get_post_thumbnail_id($id);
	
	return($article);	

}}


function get_full_post() {

	ob_start();
	global $post;
	$post = &get_post($post->ID);
	setup_postdata($post);
	the_content();
	wp_reset_postdata($post);
	$post_full = ob_get_clean();

	$post_full = str_replace(array('<code>','</code>'), array('<pre><code class="prettyprint linenums">','</code></pre>') , $post_full);
	$post_full = str_replace('[contacts]', get_contacts(), $post_full);
	$post_full = str_replace('[mailinglist]', get_mailing(), $post_full);
	
		
//	$post_full = tagify($post_full);
//	$post_full = str_replace($post->permalink, $post->shortlink.'/', $post->post_full); // replace perm with short
		
	// do links
	$post_full = click($post->post_content,$post_full);
		
	////////////////////////////////////////////////
	// replace media - only if post type is video //
	if( in_array(get_post_format($post->ID),array('video','audio')) ) {
		
		$media = get_inline_media($post->post_content);
		$post_full = str_replace($media[0], $media[2], $post_full);
			
		/* 
			make data arrays.
			foreach (array_unique($vimeos[1]) as $vimeo) $vimeo_data[] = vimeo($vimeo); 
			foreach (array_unique($images[1]) as $image) $image_data[] = array('thumbnail_url'=>$image);
			$post->post_text = str_replace($remove, '', $post->post_content);
			$post->post_vimeo = $vimeo_data;
			$post->post_image = $image_data;
		*/
		
	} // end video	

	return $post_full;
}


// find inline media //
function get_inline_media($content,$featured) {

	preg_match_all('~(?>https://vimeo.com/|http://vimeo.com/|vimeo.com/)([0-9]{7,10})~', $content, $vimeos);
	preg_match_all('~(?>https://youtu.be/|http://youtu.be/|youtu.be/|https://www.youtube.com/embed/)([a-zA-Z0-9_]{7,12})~', $content, $youtubes);
	preg_match_all('~(?>https://api.soundcloud.com/tracks/|api.soundcloud.com/tracks/|soundcloud.com/tracks/)([0-9]{7,10})~', $content, $sounds);
	
    $vimeos[2] = $youtubes[2] = $sounds[2] = array();

	foreach ($vimeos[1] as $id) $vimeos[2][] = '
	 </div>
	 <div class="video">
	  <div>
	   <iframe src="//player.vimeo.com/video/'.$id.'?badge=0&byline=0&portrait=0&title=0&color=62CCDC" style="width:100%;height:100%;" width="100%" height="100%" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen>
	    </iframe>
	   </div>
	  </div>
	 <div class="contain">';
	
	foreach ($youtubes[1] as $id) $youtubes[2][] = '
	 </div>
	 <div class="video">
	  <div>
	   <iframe src="https://www.youtube.com/embed/'.$id.'" style="width:100%;height:100%;" width="100%" height="100%" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen>
	    </iframe>
	   </div>
	  </div>
	 <div class="contain">';
	
	foreach ($sounds[1] as $id) $sounds[2][] = '
	 </div>
	 <div class="video">
	  <div>
	   <iframe width="100%" height="450" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/'.$id.'&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false&amp;visual=true">
	    </iframe>
	   </div>
	  </div>
	 <div class="contain">'; 
	  
	$videos[0] = array_merge($vimeos[0],$youtubes[0],$sounds[0]);
	$videos[1] = array_merge($vimeos[1],$youtubes[1],$sounds[1]);
	$videos[2] = array_merge($vimeos[2],$youtubes[2],$sounds[2]);
	
	if($featured) { /*
		if featured return [1]id of the [0]first item
		preferably in order in text not by network like here
		*/ return $vimeos[1][0];
	} else { /*
		return all the media found links and their id's
		so they can be found and replaced by abother function
		//if($vimeos[0]) add to merge..
		$media = array_merge($vimeos,$youtubes);
		*/ return $videos;
	}
	
}

// clickify - for posr take trimmed add to full //
function click($post_content,$post_full) {

	// do twitter handles
	preg_match_all('/(^|\s)@(\w+)/', $post_content, $handles); 
	foreach ($handles[2] as $handle) $handles[3][] = '
	<a href="http://twitter.com/'.$handle.'" target="_blank" title="head to @'.$handle.'" onclick="__gaTracker(\'send\', \'event\', \'postlink-user\', \'http://twitter.com/'.$handle.'\', \'postlink: @'.$handle.'\');">@'.$handle.'</a>'; 
	if($post_full) $post_full = str_replace(array_map('trim', $handles[0]), $handles[3], $post_full);
	else $post_content = str_replace(array_map('trim', $handles[0]), $handles[3], $post_content);
	
	// do twitter hashtags
	preg_match_all('/(^|\s)#(\w+)/', $post_content, $tags); 
	foreach ($tags[2] as $tag) $tags[3][] = '
	<a href="https://twitter.com/hashtag/'.$tag.'?src=hash" target="_blank" title="search for #'.$tag.'" onclick="__gaTracker(\'send\', \'event\', \'postlink-hashtag\', \'https://twitter.com/hashtag/'.$tag.'?src=hash\', \'postlink: #'.$tag.'\');">#'.$tag.'</a>'; 
	if($post_full) $post_full = str_replace(array_map('trim', $tags[0]), $tags[3], $post_full);
	else $post_content = str_replace(array_map('trim', $tags[0]), $tags[3], $post_content);
/*	
	// do www links
	preg_match_all('$(www\.[a-z0-9_./?=&#-]+)(?![^<>]*>)$i', $post_content, $www_links); 
	foreach ($www_links[1] as $www_link) $www_links[3][] = '<a href="http://'.$www_link.'" target="_blank" onclick="__gaTracker(\'send\', \'event\', \'postlink-web\', \'http://'.$www_link.'\', \'postlink: '.$www_link.'\');">'.$www_link.'</a>'; 
	if($post_full) $post_full = str_replace(array_map('trim', $www_links[0]), $www_links[3], $post_full);
	else $post_content = str_replace(array_map('trim', $www_links[0]), $www_links[3], $post_content);
	
	// do html links
	preg_match_all('$(https?://[a-z0-9_./?=&#-]+)(?![^<>]*>)$i', $post_content, $html_links); 
	foreach ($html_links[1] as $html_link) $html_links[3][] = '<a href="'.$html_link.'" target="_blank" onclick="__gaTracker(\'send\', \'event\', \'postlink-web\', \''.$html_link.'\', \'postlink: '.$html_link.'\');">'.$html_link.'</a>'; 
*/	
	if($post_full) $post_full = str_replace(array_map('trim', $html_links[0]), $html_links[3], $post_full);
	else $post_content = str_replace(array_map('trim', $html_links[0]), $html_links[3], $post_content);
	
	if($post_full) return $post_full;
	else return $post_content;
	
}

// replace post words with tag links //
function tagify($str) {
	$tags = get_tags();
	foreach ($tags as $tag) {
		$tag_link = get_tag_link($tag->term_id);
		$search[] = '/\b'.$tag->slug.'\b/i';
		$link[$tag->slug] = array($tag_link, $tag->name);
	}

	return preg_replace_callback($search, function($matches) use ($link) {
		$tag = $link[strtolower($matches[0])];
		return '<a href="'.$tag[0].'" title="more about '.$tag[1].'" class="text-tag" onclick="__gaTracker(\'send\', \'event\', \'postlink-tag\', \''.$tag[0].'\', \'postlink tag: '.$matches[0].'\');">'.$matches[0].'</a>';
	}, $str);
}



////////////////////////
// gt section formats //
////////////////////////
function showcase_loop($args,$look) { 

	// make layout array 
	if($look['custom']) {
		$custom = array();
		if (is_array($look['spacing'])) {
			foreach ($look['spacing'] as $value) {
				$units = explode('*', $value);
				$pad = array($units[1],$row++);
				$custom = array_pad($custom, ($units[0]+count($custom)), $pad); 
			}
		}
		$look['post_style'] = 'custom';
	}
		
	// query to get post id's
	$args = array_merge($args, array ( 'fields' => 'ids' ));
	
	$all_stickys = get_option( 'sticky_posts' );
	
	$query = new WP_Query($args);
	$sticky = array_intersect($query->posts, $all_stickys);
	$non_stick = array_diff($query->posts, $sticky);
	$articles = array_merge($sticky, $non_stick);
		
	if ( $articles ) { 
	
		foreach ($articles as $id) {
		
			$article = get_article($id); 
			$custom_fields = get_post_custom($id); 
			
			//if (!$post->post_password||$_GET[u]==$post->post_password||current_user_can(read_private_posts)) {
				//if ($post->post_status=='publish'||$_GET[preview]=='true') {
					
					$i++; $tile=''; if($i==1) $tile = ' first';
					$feature_image = wp_get_attachment_image_src($article->featured, '16x9_small')[0];
					
					switch ($look[post_style]) {
					
						case "new-test": // used for photos and video
					
		$item = '
		 <section class="'.$look['spacing'].' columns" id="post-'.$id.'"> 
		  <figure class="effect-roma"> 
		  	<img src="'.$feature_image.'" alt"'.$article->title.'"/> 
		  	<figcaption> 
		  		<h2>'.$article->title.'</h2>
		  		<p><i class="fa fa-search"></i><br/>'.truncate($article->excerpt,'200').'</p> 
		  		<span><i class="fa fa-tag"></i><br/>'.tags($id,6).'</span>
		  		<a class="frame" href="'.$article->permalink.'" alt="'.$article->title.'" onclick="__gaTracker(\'send\', \'event\', \'front-media\', \''.$article->permalink.'\', \'front full: '.$article->title.'\');">View more</a> 
		  	</figcaption> 
		  </figure> 
		 </section>'; 
		 
		 				break;
          				case "link": // current projects link

         $item = '
          <section class="'.$look['spacing'].' columns" id="post-'.$id.'"> 
           <a href="'.$article->permalink.'" onclick="__gaTracker(\'send\', \'event\', \'internal-front\', \''.$article->permalink.'\', \'front link: '.$article->title.'\');" class="more-btn">'.$article->title.'</a>
          </section>';
          				
          				break;
          				case "pop-post": // articles pop-post
          				
         $item = '
           <li class="popPost" id="post-'.$id.'"> 
            <a href="'.$article->permalink.'" onclick="__gaTracker(\'send\', \'event\', \'internal-front\', \''.$article->permalink.'\', \'front pop post: '.$article->title.'\');"> 
             <p class="popMeta">'.$custom_fields['shares'][0].' Shares</p> 
             <p class="popTitle">'.$article->title.'</p> 
             <p class="popMore">Read it »</p> 
            </a> 
           </li>';          				
          				
          				break;
          				case "custom": // auto selected with custom field
							
							if ($custom[$i-2][1]!=$custom[$i-1][1]) $tile = ' first';
         $item = '
           <div class="'.$custom[$i-1][0].$tile.'"> 
            <a href="'.$article->permalink.'" onclick="__gaTracker(\'send\', \'event\', \'internal-front\', \''.$article->permalink.'\', \'front custom: '.$article->title.'\');"><img src="'.$feature_image.'"><br/>'.$article->title.' 
            </a> custom
           </div>'; 
          	
          				break;			
          			} // end case
          
					$display[$i] = array($id, $item); 
					
				//} 
			//} 
		} // end loop
		
		// trim to chosen post amount
		if($look['items']) $display = array_slice($display,0,$look['items']); 
	
		// print content * exclude array
		foreach ($display as $data) { $loop .= $data[1]; $exclude[] = $data[0]; }
		if ($look[post_style]=='pop-post') $loop = '<ul class="clearing-thumbs small-block-grid-1 medium-block-grid-3 popPosts" data-clearing>'.$loop.'</ul>';
	
$return = ' 
   <div id="'.$look['section_id'].'" class="'.$look['section'].' '.$look['section_class'].'"> 
    <div class="inner"> 
     <div class="wrap"> 
      <article class="block row"> 
       <header class="large-12 columns">'.$look['text'].'</header> 
       '.$loop.'
       '.$look['tail'].'
      </article> 
     </div> 
    </div> 
   </div> 
';
		
	} return array($exclude,$return);
	
} // end function



///////////////////
// Get post info //
///////////////////

// Get post tags //
function tags($id,$many) {
	$data = array();
	$data = get_the_tags($id);
	krsort($data); /* reverse orig so right later */
	foreach ($data as $item) $sorted[$item->count.'-'.$x++] = $item;
	krsort($sorted);
	foreach ($sorted as $item) {
		$title = 'View all '.$item->count.' posts in '.$item->name;
		if($str=$item->description) {
			// limit to character length with out breaking word //
			$str = wordwrap($str, 100);
			$str = explode("\n", $str);
			$str = $str[0] . '...';
			$title .= ' ~ '.$str;
		}
		$links[] = '<a href="'.get_tag_link($item->term_id).'" title="'.$title.'" onclick="__gaTracker(\'send\', \'event\', \'post-tag\', \''.get_tag_link($item->term_id).'\', \'post tag: '.$item->name.'\');">'.$item->name.'</a>';
	}
	$links = array_slice($links, 0, $many);
	if ($links) return(implode(', ', $links));
	else return(false);	
}

// Get post catogorys //
function categorys($id,$many) {
	$data = array();
	$data = get_the_category($id);
	krsort($data); /* reverse orig so right later */
	foreach ($data as $item) $sorted[$item->count.'-'.$x++] = $item;
	krsort($sorted);
	foreach ($sorted as $item) {
		$title = 'View all '.$item->count.' posts in '.$item->name;
		if($str=$item->description) {
			// limit to character length with out breaking word //
			$str = wordwrap($str, 100);
			$str = explode("\n", $str);
			$str = $str[0] . '...';
			$title .= ' ~ '.$str;
		}
		$links[] = '<a href="'.get_category_link($item->term_id).'" title="'.$title.'" onclick="__gaTracker(\'send\', \'event\', \'post-category\', \''.get_category_link($item->term_id).'\', \'post category: '.$item->name.'\');">'.$item->name.'</a>';
	}
	$links = array_slice($links, 0, $many);
	if ($links) return('in&nbsp;<strong>'.implode(' & ', $links).'</strong>');
	else return(false);
}

// Make single category link //
function category($slug) {
	$data = get_category_by_slug($slug);
	if($data->description) $data->description = ' | '.$data->description;
	if($data->count=='1') $data->count = $data->count.' post'; else $data->count = $data->count.' posts';
	return('<a href="'.esc_url(get_category_link($data->cat_ID)).'" title="Have a look at the '.$data->count.' other posts in '.$data->name.' ~ '.$data->description.'" onclick="__gaTracker(\'send\', \'event\', \'category\', \''.esc_url(get_category_link($data->cat_ID)).'\', \'category: '.$data->category_nicename.'\');">#'._s($data->cat_ID).''.$data->category_nicename.'</a>');
}

// Get author //
function author($id) {
	$u = get_userdata($id);
	return '<a href="'.get_author_posts_url($id).'" title="Go to '.count_user_posts($id).' posts by '.ucfirst($u->data->user_nicename).'"  onclick="__gaTracker(\'send\', \'event\', \'author\', \''.get_author_posts_url($id).'\', \'author: '.$u->data->display_name.'\');">'.$u->data->display_name.'</a>';
}

// Get author name //
function name($id) {
	$u = get_userdata($id);
	return $u->data->display_name;
}

// Get contacts //
function get_contacts(){
/*
	$args = array(
		'blog_id'		=> $GLOBALS['blog_id'],
		'role'			=> '',
		'exclude'		=> array(),
		'orderby'		=> 'post_count', // 'nicename', 'registered', 'display_name', 'post_count'
		'order'			=> 'DESC',
		'count_total'	=> true,
		'fields'		=> array('user_nicename', 'user_email', 'user_url', 'user_registered', 'display_name'),
		'who'			=> 'authors'
	 ); 
	$users = get_users( $args ); 
	
	foreach ($users as $id => $data) {
		$return .= '<h2>'.ucwords($data->user_nicename).'</h2><a href="mailto:'.$data->user_email.'">'.$data->user_email.'</a> 
		- <a href="'.$data->user_url.'">'.$data->user_url.'</a><br/>';
		// display_name, user_registered
	}
*/	
	$return = '
<form id="ajax-contact" class="slack" method="post" action="'.get_bloginfo('template_url').'/parts/mailer.php">
 <div class="row">
  <div class="small-12 medium-4 columns">
   <label for="name">Name:</label>
   <input type="text" id="name" name="name" required>
  </div>
  <div class="small-12 medium-4 columns">
   <label for="email">Email:</label>
   <input type="email" id="email" name="email" required>
  </div>
  <div class="small-12 medium-4 columns">
   <label for="reason">Reason for messsage:</label>
   <select type="email" id="reason" name="reason" required>
    <option value="f13-enquiry">General</option>
    <option value="f13-enquiry">Photography</option>
    <option value="f13-film">Film work</option>
    <option value="f13-review">Leave a review</option>
    <option value="f13-modeling">Modeling</option>
   </select>
  </div> 
  <div class="small-12 columns">
   <label for="message">Message:</label>
   <textarea id="message" name="message" required></textarea>
  </div>
  <div class="row">
    <div class="small-12 medium-6 large-4 small-centered columns">
     <button id="form-button" type="submit" class="small-12 column">Send</button>
    </div>
    <span id="form-messages" class="message small-12 column"></span>
  </div>
 </div>
</form>';
		
	return $return;
}

function get_mailing(){
	$return = '
<form id="ajax-contact" class="slack" method="post" action="'.get_bloginfo('template_url').'/parts/mailer_2.php">
 <div class="row">
  <div class="small-12 medium-6 columns">
   <label for="name">Name:</label>
   <input type="text" id="name" name="name" required>
  </div>
  <div class="small-12 medium-6 columns">
   <label for="email">Email:</label>
   <input type="email" id="email" name="email" required>
  </div>
  <div class="small-12 columns" style="display:none">
   <label for="message">Message:</label>
   <textarea id="message" name="message"></textarea>
  </div>
  <div class="row">
    <div class="small-12 medium-6 large-4 small-centered columns">
     <button id="form-button" type="submit" class="small-12 column">Join the mailing list?</button>
    </div>
    <span id="form-messages" class="message small-12 column"></span>
  </div>
 </div>
</form>';
		
	return $return;
}


// iconify a word //
function iconify($var, $default) {
	$icons = array( 
		'yourphoto' => 'fa-heart',
		'ideas' => 'fa-lightbulb-o', 
		'knoll' => 'fa-anchor', 
		'timelapse' => 'fa-cloud',  
		'photography' => 'fa-camera', 
		'photo' => 'fa-camera-retro', 
		'development' => 'fa-desktop', 
		'quote' => 'fa-quote-left', 
		'radio' => 'fa-music', 
		'travel' => 'fa-tree',
		'audio' => 'fa-microphone',
		'link' => 'fa-paperclip',
		'archive' => 'fa-paper-plane',
		'fisheye' => 'fa-eye', 
		'contact' => 'fa-phone',
		'uberzeal' => 'fa-heartbeat fa-spin fa-2x',
		'loading' => 'fa-spinner fa-pulse fa-2x',
	);
	$location = array(
		'sydney','new south wales','melbourne','victoria','brisbane','queensland','perth','western australia','adelaide','gold coast',
		'hayman','lizard island',
	);
	if($icons[$var]!='') return $icons[$var];
	else if(in_array($var,array('dslr','film','short'))) return 'fa-video-camera';
	else if(in_array($var,$location)) return 'fa-paper-plane';
	else return $default;	
}

// get attachment id from url //
function get_attachment_id($image_src) {
	global $wpdb;
	$query = "SELECT ID FROM {$wpdb->posts} WHERE guid='$image_src'";
	$id = $wpdb->get_var($query);
	return $id;
}

// set header //
function get_photo($term) {
	// try by category 
	$args = array(
		'post_type' => 'attachment',
		'post_status' => 'inherit',
		'category_name' => $term,
	);
	$query = new WP_Query( $args );	
	// try by tag
	if(!$image=$query->posts[array_rand($query->posts, 1)]) {
		$args = array(
			'post_type' => 'attachment',
			'post_status' => 'inherit',
			'tag' => $term,
		);
		$query = new WP_Query( $args );	
		$image=$query->posts[array_rand($query->posts, 1)];
	}	
	return $image->guid;
}



///////////////////
// Time and Date //
///////////////////

// linkify dates //
function link_dates($time) {
	$d = explode('-',date('Y-m-d-H-i-s-l-F-jS-g:ia',stamp($time)));
	$link = array(
		$d[6].' ' => $d[0].'/'.$d[1].'/'.$d[2],	/* Day */
		$d[7].' ' => $d[0].'/'.$d[1],	/* Month */
		$d[8].' ' => $d[0].'/'.$d[1].'/'.$d[2],	/* DDth */
		$d[0].' ' => $d[0],	/* Year */
	);
	foreach ($link as $name => $link) {
		$return .= '<a href="/'.$link.'">'.$name.'</a>';
	}
	return($return.'at&nbsp;'.$d[9]); 
}

// Linkify Dates - gt //
function time_tag($time) {
	$d = explode('|',date('Y|m|d|l|F|jS|g:ia|c',stamp($time)));
	$link = array(
		$d[4] => $d[0].'/'.$d[1], /* Month: Text */ 
		$d[5] => $d[0].'/'.$d[1].'/'.$d[2], /* Day: DD & Suffix */ 
		$d[0].' ' => $d[0], /* Year: YYYY */
	);
	foreach ($link as $name => $link) {
		$str .= '<a href="/'.$link.'" alt="Posts for '.$name.'">'.$name.'</a> ';
	}
	return('<time class="entry-time" itemprop="datePublished" datetime="'.$d[7].'">'.$str.'</time>');
}

// prety date //
function pretty_date($data, $format='full') {
	$type = array(
		'full' => 'l F jS Y \a\t&\nb\sp;g:ia',
		'date' => 'l F jS Y'
	);
	// return in chosen format
	return(date($type[$format],stamp($data)));
}
// convert wp to stamp used above //
function stamp($data) {
	$parts = explode(' ', $data);
	$date = explode('-', $parts[0]);
	$time = explode(':', $parts[1]);
	return(mktime($time[0], $time[1], $time[2], $date[1], $date[2], $date[0]));	
}



//////////////////////////
// Get API data and RSS //
//////////////////////////

// get tweets // 
function tweet($user='f13tv',$amount='1') {

	require_once('tweet-loader/index.php');
	$tweets = new TweetPHP(array(
		'twitter_screen_name'	=> $user,
		'cachetime'             => 60 * 5,
		'tweets_to_display'     => $amount,
		'ignore_replies'        => true,
		'ignore_retweets'       => false
	));
	$tweet_array = $tweets->get_tweet_array();

	foreach($tweet_array as $key => $t ){
	
		if($t["retweeted_status"]) $t = $t["retweeted_status"]; // if retweet, get oroginal..

		// replace url's and links
		foreach ($t['entities']['urls'] as $value) {
			$search[] = $value['url'];
			$replace[] = '<a href="'.$value['expanded_url'].'"
			onclick="__gaTracker(\'send\', \'event\', \'twitter-link\', \''.$value['expanded_url'].'\', \'twitter link: '.$value['expanded_url'].'\');" 
			target="_blank" title="'.$value['expanded_url'].'">'.$value['display_url'].'</a>';
		}
		if (is_array($t['entities']['media'])) {
			foreach ($t['entities']['media'] as $value) {
				$search[] = $value['url'];
				$replace[] = '<a href="'.$value['expanded_url'].'" 
				onclick="__gaTracker(\'send\', \'event\', \'twitter-link\', \''.$value['expanded_url'].'\', \'twitter link: '.$value['expanded_url'].'\');"
				target="_blank" title="'.$value['expanded_url'].'">'.$value['display_url'].'</a>';
			}
		}
		$status = str_replace($search, $replace, $t["text"]);
		$status = preg_replace('$(https?://[a-z0-9_./?=&#-]+)(?![^<>]*>)$i', ' <a href="$1" 
		onclick="__gaTracker(\'send\', \'event\', \'twitter-link\', \'$1\', \'twitter link: $1\');" 
		target="_blank" title="view online.">$1</a> ', $status." ");
		$status = preg_replace('$(www\.[a-z0-9_./?=&#-]+)(?![^<>]*>)$i', '<a href="http://$1" 
		onclick="__gaTracker(\'send\', \'event\', \'twitter-link\', \'$1\', \'twitter link: $1\');" 
		target="_blank" title="view online.">$1</a> ', $status." ");
		$status = preg_replace('/(^|\s)@(\w+)/','\1<a href="http://twitter.com/\2" 
		onclick="__gaTracker(\'send\', \'event\', \'twitter-user\', \'http://twitter.com/\2\', \'twitter user: @\2\');" 
		target="_blank" title="head to @\2">@\2</a>',$status); // users
		$status = preg_replace('/(^|\s)#(\w+)/','\1<a href="https://twitter.com/hashtag/\2?src=hash" 
		onclick="__gaTracker(\'send\', \'event\', \'twitter-hashtag\', \'https://twitter.com/hashtag/\2?src=hash\', \'twitter hashtag: #\2\');" 
		target="_blank" title="search for #\2">#\2</a>',$status); // tag

		// user deatils
		$user = $t["user"]["screen_name"];
		$date = explode(" ", $t["created_at"]);
	
		$tweet .= '<li>
			<p class="tweet">'.$status.'</p>
			<p class="intent">
				<a href="https://twitter.com/intent/favorite?tweet_id='.$t["id"].'" onclick="__gaTracker(\'send\', \'event\', \'twitter-favorite\', \'https://twitter.com/intent/favorite?tweet_id='.$t["id"].'\', \'twitter favorite: '.$t["text"].'\');" title="favorite" target="_blank"><i class="fa fa-star"></i></a>
				<a href="https://twitter.com/intent/retweet?tweet_id='.$t["id"].'" onclick="__gaTracker(\'send\', \'event\', \'twitter-retweet\', \'https://twitter.com/intent/retweet?tweet_id='.$t["id"].'\', \'twitter retweet: '.$t["text"].'\');" title="retweet" target="_blank"><i class="fa fa-retweet"></i></a>
				<a href="https://twitter.com/intent/tweet?in_reply_to='.$t["id"].'" onclick="__gaTracker(\'send\', \'event\', \'twitter-reply\', \'https://twitter.com/intent/tweet?in_reply_to='.$t["id"].'\', \'twitter reply: '.$t["text"].'\');" title="reply" target="_blank"><i class="fa fa-reply"></i></a>
			</p><p class="ref">	
				<a href="https://twitter.com/'.$user.'/status/'.$t["id"].'" onclick="__gaTracker(\'send\', \'event\', \'twitter-view\', \'https://twitter.com/'.$user.'/status/'.$t["id"].'\', \'twitter view: '.$t["text"].'\');" target="_blank" title="">Tweet</a> by <a href="http://twitter.com/'.$user.'" onclick="__gaTracker(\'send\', \'event\', \'twitter-user\', \'http://twitter.com/'.$user.'\', \'twitter user: '.$user.'\');" target="_blank" title="@'.$user.'">'.$t["user"]["name"].'</a> on '.$date[0].' '.$date[1].' '.$date[2].'
			</p>
		</li>';
		
		return '<ul>'.$tweet.'</ul>';
	}
}

// get last-fm //
function last_fm($time,$type) {

	$r = array(
		'artists' => array(
			'week' => 'http://ws.audioscrobbler.com/2.0/user/martyish/weeklyartistchart.xml',
			'qtr' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topartists.xml?period=3month',
			'half' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topartists.xml?period=6month',
			'full' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topartists.xml?period=12month',
			'all' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topartists.xml',
		),
		'albums' => array(
			'qtr' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topalbums.xml?period=3month',
			'half' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topalbums.xml?period=6month',
			'full' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topalbums.xml?period=12month',
			'all' => 'http://ws.audioscrobbler.com/2.0/user/martyish/topalbums.xml',
		),
		'tracks' => array(
			'week' => 'http://ws.audioscrobbler.com/2.0/user/martyish/weeklytrackchart.xml',
			'qtr' => 'http://ws.audioscrobbler.com/2.0/user/martyish/toptracks.xml?period=3month',
			'half' => 'http://ws.audioscrobbler.com/2.0/user/martyish/toptracks.xml?period=6month', 
			'full' => 'http://ws.audioscrobbler.com/2.0/user/martyish/toptracks.xml?period=12month',
			'all' => 'http://ws.audioscrobbler.com/2.0/user/martyish/toptracks.xml',
		),
		'feed' => array(
			'loved' => 'http://ws.audioscrobbler.com/2.0/user/martyish/lovedtracks.rss',
			'played' => 'http://ws.audioscrobbler.com/1.0/user/martyish/recenttracks.rss',
		)
	);
	
    if ($content = file_get_contents($r[$type][$time])) {
    
	    $x = new SimpleXmlElement($content);
    
		/* I dont think two foreach things work like this :(
		if(!$type=='feed') {*/
			if(array_key_exists("track",$x)) $items = $x->track;
			else if(array_key_exists("album",$x)) $items = $x->album;
			else if(array_key_exists("artist",$x)) $items = $x->artist;
			foreach($items as $item) {
				if(!array_key_exists("name",$item->artist)) $artist = (string) $item->artist;
				else $artist = (string) $item->artist->name;
				$result[] = array(
					'artist' => $artist,
					'name' => (string) $item->name,
					'url' => (string) $item->url,
					'image' => (string) $item->image,
					'plays' => (string) $item->playcount,
					'duration' => (string) $item->duration
				);
			}
		/*} else { 
			foreach ($x->channel->item as $item) {
				$result[] = array(
					'title' => (string) $item->title,
					'url' => (string) $item->link,
					'date' => (string) $item->pubDate,
					'guid' => (string) $item->guid,
					'artist_url' => (string) $item->description
				);
			}
		}*/	
		$search = explode('/', $result[0][url]);
		$url = 'http://www.google.com/search?&sourceid=navclient&btnI=I&q='.$search[4].'+'.$search[6].'&tbm=vid&tbs=hq:h';
	
		return '<a href="'.$url.'" onclick="__gaTracker(\'send\', \'event\', \'outbound-song\', \''.$url.'\', \'song: '.$result[0][name].' by '.$result[0][artist].'\');" target="_blank">For your listening pleasure, we reccomend '.$result[0][name].' by '.$result[0][artist].' :)</a>';
		
	}
}

// get vimeo videos //
function vimeo($id,$channel='f13') {
	$url = 'https://vimeo.com/'.$id;
	$vid = json_decode(file_get_contents('http://vimeo.com/api/oembed.json?url='.$url),true);
	$vid[aspect] = aspect($vid[width],$vid[height]);
	$channel_vids = json_decode(file_get_contents('http://vimeo.com/api/v2/channel/'.$channel.'/videos.json'),true);
	foreach ($channel_vids as $data) $vids[] = $data[id]; 
	if(in_array($vid[video_id],$vids)) $vid[url] = 'https://vimeo.com/couchmode/channels/265673/sort:preset/'.$vid[video_id];
	else $vid[url] = $url;
	return($vid);
}

// get users sounds (soundcloud) //
function sounds($userid="40706431",$amount=3) {

	$clientid = "f4a62ad0e5bdb9dcfb7b4777fa94226a"; // API Client ID
	$soundcloud_url = "http://api.soundcloud.com/users/{$userid}/tracks.json?client_id={$clientid}";
	$tracks_json = file_get_contents($soundcloud_url);
	$tracks = json_decode($tracks_json);
	
	$user = $tracks[0]->user;
	$url = $user->permalink_url;
	
	if($user) {
		foreach (array_slice($tracks,0,$amount) as $track) {
			$loop .= "<article class='small-6 medium-4 columns'><iframe width='100%' height='250px' scrolling='no' frameborder='no' src='https://w.soundcloud.com/player/?url=".$track->uri."&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false&amp;visual=true'></iframe></article>";
/*	
			$return .= " 
				ID ".$track->id."
				duration ".$track->duration."
				tag list ".$track->tag_list."
				permalink ".$track->permalink."
				downloadable ".$track->downloadable."
				purchase url ".$track->purchase_url."
				purchase title ".$track->purchase_title."
				title ".$track->title."
				description ".$track->description."
				uri ".$track->uri."
			";
*/		}
		return array("
<article class='post soundcloud'> 
 <header class='title'> 
  <h1>Sounds for your listening pleasure</h1>
  <p><a href=".$user->permalink_url." target='_blank'><img class='circle' src='".$user->avatar_url."' />".$user->username."</a></p>
 </header>
 <section class='row'>".$loop."</section>
 <a href=".$user->permalink_url." target='_blank'><i class='hovicon effect-1 sub-a'><b class='fa fa-soundcloud'></b></i></a>
</article>",$user->permalink_url,$tracks);
	}
}
 
 
// social media share count //
function get_shares($url) { 
	$json_string = file_get_contents("http://www.linkedin.com/countserv/count/share?url=$url&format=json");
	$json = json_decode($json_string, true);
	return intval( $json['count'] );
}
function get_tweets($url) {
	$json_string = file_get_contents('http://urls.api.twitter.com/1/urls/count.json?url=' . $url);
	$json = json_decode($json_string, true);
	return intval( $json['count'] );
}
function get_likes($url) {
	$json_string = file_get_contents('http://graph.facebook.com/?ids=' . $url);
	$json = json_decode($json_string, true);
	return intval( $json[$url]['shares'] );
}
function get_plusones($url) {
	$curl = curl_init();
	curl_setopt($curl, CURLOPT_URL, "https://clients6.google.com/rpc");
	curl_setopt($curl, CURLOPT_POST, 1);
	curl_setopt($curl, CURLOPT_POSTFIELDS, '[{"method":"pos.plusones.get","id":"p","params":{"nolog":true,"id":"' . $url . '","source":"widget","userId":"@viewer","groupId":"@self"},"jsonrpc":"2.0","key":"p","apiVersion":"v1"}]');
	curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-type: application/json'));
	curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
	$curl_results = curl_exec ($curl);
	curl_close ($curl);
	$json = json_decode($curl_results, true);
	return intval( $json[0]['result']['metadata']['globalCounts']['count'] );
}
// look at shares for all variations of post url
// uses all the above functons..
function total($url1,$url2/*,$url3*/){
	
	foreach ( array($url1,$url2/*,$url3*/) as $url ) {
		$tweets[]	= get_tweets($url);
		$shares[]	= get_shares($url);
		$likes[]	= get_likes($url);
		$plusones[]	= get_plusones($url);
	};
	
	// make xK if in thousands..
	// return array_sum($tweets) + array_sum($shares) + array_sum($plusones) + $likes[0]; correct.. technically as fb seems to make all links the same
	$total = array_sum($tweets) + array_sum($shares) + array_sum($plusones) + array_sum($likes); // like better :p ovs because fb is x 3.. wrong tho :/
	
	if($total>=1000)return '<span title="'.number_format($total).' to be exact..">'.round($total/1000).'k</span>';
	else return number_format($total);
		
}


// send slack message //
function slack($message, $channel = "#cybot", $user = "Bot") {
	$data =	"payload=" . json_encode(array(
		"username"		=> $user,
		"channel"		=>  $channel,
		"text"			=>  $message,
		"icon_url"		=> "http://s.f13.me/q1.png",
		"unfurl_links"	=> true, 
	));
	$ch = curl_init("https://hooks.slack.com/services/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"); // f13tv
	curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
	curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$result = curl_exec($ch);
	curl_close($ch);
	return $result;	
}


// google location //
function getCoordinates($address){
	$address = str_replace(" ", "+", $address); 
	$url = "http://maps.google.com/maps/api/geocode/json?sensor=false&address=$address"; 
	$response = file_get_contents($url); 
	$json = json_decode($response,TRUE); 

	return ($json['results'][0]['geometry']['location']['lat'].",".$json['results'][0]['geometry']['location']['lng']); 
}



/////////////////
// HANDY STUFF //
/////////////////

// truncate - used in post //
function truncate($str,$length) {
	$str = strip_tags($str);
	if (strlen($str) >= $length) return substr($str, 0, $length).'...';
	else return $str;
}

// if else //
function _ie($var, $true, $false) { if($var) return $true; else return $false; }

// if exists //
function _i($var, $before, $after) { if($var) return $before.''.__($var,'f13').''.$after; }

// maths //
function gcd($a,$b) {
	$a = abs($a); $b = abs($b);
	if( $a < $b) list($b,$a) = Array($a,$b);
	if( $b == 0) return $a;
	$r = $a % $b;
	while($r > 0) {
		$a = $b;
		$b = $r;
		$r = $a % $b;
	}
	return $b;
}

// aspect ratio //
function aspect($width,$height) {
	$g = gcd($height,$width);
	$w_rat = $width/$g;
	$h_rat = $height/$g;
	$aspect = $w_rat.':'.$h_rat;
	$ratio = ($h_rat/$w_rat)*100;
	return Array($aspect,$ratio,$w_rat,$h_rat);
}



///////////
// ADMIN //
///////////

// dump var //
function _d($var) {
	if($var) {
		if(!is_string($var)) $print = '<code><pre>'.var_export($var, 'true').'</pre></code>'; 
		else $print = '<blockquote><i>'.$var.'</i></blockquote>';
		return _a('<div class="dom">'.$print.'</div>');
	}
}
// if admin print //
function _a($var) { if (current_user_can( 'manage_options' )) return $var; }



//////////////
// LANGUAGE //
//////////////
function error($message) {
	$lang = array(
		'no-posts' => array(
			'Sorry, no posts matched your criteria', 
			'Sorry about this... Try heading back to out <a href="/">front page</a> and maybe you will find something that has a bit more to look at..'
		)
	);
	return($lang[$message]);
}



////////////////
// DOM HEIGHT //
////////////////
/*
if(!isset($_COOKIE['screen'])) {
	echo '<script type="text/javascript">
		width	= screen.width; 
		height	= screen.height; 
		inner	= window.innerHeight;
		document.cookie = "screen="+width+"|"+height+"|"+inner;
	</script>';
} else {
	$screen=$_COOKIE['screen'];
	$screen=explode ('X', $screen);
	echo $screen[0].' x '.$screen[1].' x '.$screen[1];
}
*/

//update_post_meta(2, 'phone', '0418878047');
